@@ -15,5 +15,6 @@ def test_deserialize_with_key_map():
 def test_deserialized_with_sub_obj_key_map():
     serialized = b'\x92\xd4b\x15\xc6\x00\x00\x00\x17\xf0\x06\x94c\xa4hoge\x92\xa6coucou*\xa4huga'
     key_map = ['Age', 'FirstName', ('MySubObj', ['MyStr', 'MyInt']), 'LastName']
-    assert deserialize(serialized, key_map) == {'Age': 99, 'FirstName': 'hoge',
+    deserialized =deserialize(serialized, key_map)
+    assert deserialized == {'Age': 99, 'FirstName': 'hoge',
                                                 'MySubObj': {'MyStr': 'coucou', 'MyInt': 42}, 'LastName': 'huga'}
